( cd usr/share/doc/HTML/et/kghostview ; rm -rf common )
( cd usr/share/doc/HTML/et/kghostview ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kview ; rm -rf common )
( cd usr/share/doc/HTML/et/kview ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kamera ; rm -rf common )
( cd usr/share/doc/HTML/et/kamera ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kgamma ; rm -rf common )
( cd usr/share/doc/HTML/et/kgamma ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kdvi ; rm -rf common )
( cd usr/share/doc/HTML/et/kdvi ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcoloredit ; rm -rf common )
( cd usr/share/doc/HTML/et/kcoloredit ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ksnapshot ; rm -rf common )
( cd usr/share/doc/HTML/et/ksnapshot ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kpdf ; rm -rf common )
( cd usr/share/doc/HTML/et/kpdf ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kooka ; rm -rf common )
( cd usr/share/doc/HTML/et/kooka ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kuickshow ; rm -rf common )
( cd usr/share/doc/HTML/et/kuickshow ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kolourpaint ; rm -rf common )
( cd usr/share/doc/HTML/et/kolourpaint ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kruler ; rm -rf common )
( cd usr/share/doc/HTML/et/kruler ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kiconedit ; rm -rf common )
( cd usr/share/doc/HTML/et/kiconedit ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kpovmodeler ; rm -rf common )
( cd usr/share/doc/HTML/et/kpovmodeler ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/common ; rm -rf 1.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/1.png 1.png )
( cd usr/share/doc/HTML/et/common ; rm -rf 10.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/10.png 10.png )
( cd usr/share/doc/HTML/et/common ; rm -rf 2.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/2.png 2.png )
( cd usr/share/doc/HTML/et/common ; rm -rf 3.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/3.png 3.png )
( cd usr/share/doc/HTML/et/common ; rm -rf 4.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/4.png 4.png )
( cd usr/share/doc/HTML/et/common ; rm -rf 5.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/5.png 5.png )
( cd usr/share/doc/HTML/et/common ; rm -rf 6.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/6.png 6.png )
( cd usr/share/doc/HTML/et/common ; rm -rf 7.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/7.png 7.png )
( cd usr/share/doc/HTML/et/common ; rm -rf 8.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/8.png 8.png )
( cd usr/share/doc/HTML/et/common ; rm -rf 9.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/9.png 9.png )
( cd usr/share/doc/HTML/et/common ; rm -rf appheader.html )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/appheader.html appheader.html )
( cd usr/share/doc/HTML/et/common ; rm -rf artistic-license.html )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd usr/share/doc/HTML/et/common ; rm -rf bottom-left.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
( cd usr/share/doc/HTML/et/common ; rm -rf bottom-middle.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
( cd usr/share/doc/HTML/et/common ; rm -rf bottom-right.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
( cd usr/share/doc/HTML/et/common ; rm -rf bottom1.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd usr/share/doc/HTML/et/common ; rm -rf bottom2.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd usr/share/doc/HTML/et/common ; rm -rf bsd-license.html )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd usr/share/doc/HTML/et/common ; rm -rf docheadergears.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd usr/share/doc/HTML/et/common ; rm -rf doctop1.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd usr/share/doc/HTML/et/common ; rm -rf doctop1a.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd usr/share/doc/HTML/et/common ; rm -rf doctop1b.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd usr/share/doc/HTML/et/common ; rm -rf doctop2.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd usr/share/doc/HTML/et/common ; rm -rf doxygen.css )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd usr/share/doc/HTML/et/common ; rm -rf favicon.ico )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/favicon.ico favicon.ico )
( cd usr/share/doc/HTML/et/common ; rm -rf fdl-license )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd usr/share/doc/HTML/et/common ; rm -rf fdl-license.html )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd usr/share/doc/HTML/et/common ; rm -rf fdl-notice.html )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/fdl-notice.html fdl-notice.html )
( cd usr/share/doc/HTML/et/common ; rm -rf footer.html )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/footer.html footer.html )
( cd usr/share/doc/HTML/et/common ; rm -rf gpl-license )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd usr/share/doc/HTML/et/common ; rm -rf gpl-license.html )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd usr/share/doc/HTML/et/common ; rm -rf grad.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/grad.png grad.png )
( cd usr/share/doc/HTML/et/common ; rm -rf header.html )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/header.html header.html )
( cd usr/share/doc/HTML/et/common ; rm -rf headerbg.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd usr/share/doc/HTML/et/common ; rm -rf kde-common.css )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd usr/share/doc/HTML/et/common ; rm -rf kde-default.css )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd usr/share/doc/HTML/et/common ; rm -rf kde-localised.css.template )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd usr/share/doc/HTML/et/common ; rm -rf kde-web.css )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd usr/share/doc/HTML/et/common ; rm -rf kde_gear_64.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/kde_gear_64.png kde_gear_64.png )
( cd usr/share/doc/HTML/et/common ; rm -rf kde_logo.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
( cd usr/share/doc/HTML/et/common ; rm -rf kde_logo_bg.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
( cd usr/share/doc/HTML/et/common ; rm -rf kmenu.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd usr/share/doc/HTML/et/common ; rm -rf lgpl-license )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd usr/share/doc/HTML/et/common ; rm -rf lgpl-license.html )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd usr/share/doc/HTML/et/common ; rm -rf mainfooter.html )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd usr/share/doc/HTML/et/common ; rm -rf mainheader.html )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd usr/share/doc/HTML/et/common ; rm -rf qpl-license.html )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd usr/share/doc/HTML/et/common ; rm -rf shadow.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd usr/share/doc/HTML/et/common ; rm -rf top-left.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/top-left.png top-left.png )
( cd usr/share/doc/HTML/et/common ; rm -rf top-middle.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
( cd usr/share/doc/HTML/et/common ; rm -rf top-right-konqueror.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
( cd usr/share/doc/HTML/et/common ; rm -rf web-docbottom.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd usr/share/doc/HTML/et/common ; rm -rf web-doctop.png )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd usr/share/doc/HTML/et/common ; rm -rf x11-license.html )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd usr/share/doc/HTML/et/common ; rm -rf xml.dcl )
( cd usr/share/doc/HTML/et/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd usr/share/doc/HTML/et/ark ; rm -rf common )
( cd usr/share/doc/HTML/et/ark ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kwallet ; rm -rf common )
( cd usr/share/doc/HTML/et/kwallet ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kdf ; rm -rf common )
( cd usr/share/doc/HTML/et/kdf ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kfloppy ; rm -rf common )
( cd usr/share/doc/HTML/et/kfloppy ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcharselect ; rm -rf common )
( cd usr/share/doc/HTML/et/kcharselect ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/irkick ; rm -rf common )
( cd usr/share/doc/HTML/et/irkick ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcmlirc ; rm -rf common )
( cd usr/share/doc/HTML/et/kcmlirc ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kjots ; rm -rf common )
( cd usr/share/doc/HTML/et/kjots ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ktimer ; rm -rf common )
( cd usr/share/doc/HTML/et/ktimer ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kedit ; rm -rf common )
( cd usr/share/doc/HTML/et/kedit ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/blockdevices ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/blockdevices ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/memory ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/memory ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/ioports ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/ioports ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/opengl ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/opengl ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/samba ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/samba ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/processor ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/processor ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/partitions ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/partitions ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/devices ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/devices ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/pci ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/pci ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/pcmcia ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/pcmcia ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/nics ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/nics ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/cdinfo ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/cdinfo ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/protocols ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/protocols ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/usb ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/usb ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/dma ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/dma ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/sound ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/sound ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/xserver ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/xserver ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/interrupts ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/interrupts ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kinfocenter/scsi ; rm -rf common )
( cd usr/share/doc/HTML/et/kinfocenter/scsi ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ksim ; rm -rf common )
( cd usr/share/doc/HTML/et/ksim ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kcmlowbatwarn ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/laptop ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/laptop ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/powerctrl ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/powerctrl ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kcmlowbatcrit ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kcmktalkd ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kcmktalkd ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kxmlrpcd ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kxmlrpcd ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/lanbrowser ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/lanbrowser ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kalarmd ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kalarmd ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kmixcfg ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kmixcfg ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/crypto ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/crypto ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kcmtaskbar ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kcmtaskbar ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/keyboard ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/keyboard ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/filetypes ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/filetypes ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/language ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/language ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kcmfontinst ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kcmfontinst ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/background ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/background ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/useragent ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/useragent ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/mouse ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/mouse ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/panelappearance ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/panelappearance ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/clock ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/clock ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/spellchecking ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/spellchecking ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kcmkonsole ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kcmkonsole ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/icons ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/icons ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/cookies ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/cookies ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/colors ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/colors ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/windowmanagement ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/windowmanagement ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/cache ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/cache ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/fonts ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/fonts ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/filemanager ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/filemanager ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/bell ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/bell ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/performance ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/performance ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/panel ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/panel ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kwindecoration ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kwindecoration ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/energy ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/energy ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kcmstyle ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kcmstyle ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kcmlaunch ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kcmlaunch ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/smb ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/smb ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/email ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/email ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kcmaccess ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kcmaccess ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/netpref ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/netpref ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/proxy ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/proxy ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/desktop ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/desktop ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/khtml ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/khtml ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kdm ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kdm ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/arts ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/arts ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/helpindex ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/helpindex ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/passwords ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/passwords ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/ebrowsing ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/ebrowsing ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kcmnotify ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kcmnotify ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/keys ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/keys ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/desktopbehavior ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/desktopbehavior ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kcmcss ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kcmcss ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/kcmsmserver ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/kcmsmserver ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcontrol/screensaver ; rm -rf common )
( cd usr/share/doc/HTML/et/kcontrol/screensaver ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/khexedit ; rm -rf common )
( cd usr/share/doc/HTML/et/khexedit ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcalc ; rm -rf common )
( cd usr/share/doc/HTML/et/kcalc ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/KRegExpEditor ; rm -rf common )
( cd usr/share/doc/HTML/et/KRegExpEditor ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/superkaramba ; rm -rf common )
( cd usr/share/doc/HTML/et/superkaramba ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kgpg ; rm -rf common )
( cd usr/share/doc/HTML/et/kgpg ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kpf ; rm -rf common )
( cd usr/share/doc/HTML/et/kpf ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kdict ; rm -rf common )
( cd usr/share/doc/HTML/et/kdict ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kget ; rm -rf common )
( cd usr/share/doc/HTML/et/kget ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kwifimanager ; rm -rf common )
( cd usr/share/doc/HTML/et/kwifimanager ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ktalkd ; rm -rf common )
( cd usr/share/doc/HTML/et/ktalkd ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/lisa ; rm -rf common )
( cd usr/share/doc/HTML/et/lisa ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/krfb ; rm -rf common )
( cd usr/share/doc/HTML/et/krfb ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ksirc ; rm -rf common )
( cd usr/share/doc/HTML/et/ksirc ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/knewsticker ; rm -rf common )
( cd usr/share/doc/HTML/et/knewsticker ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kppp ; rm -rf common )
( cd usr/share/doc/HTML/et/kppp ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/krdc ; rm -rf common )
( cd usr/share/doc/HTML/et/krdc ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kopete ; rm -rf common )
( cd usr/share/doc/HTML/et/kopete ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/lilo-config ; rm -rf common )
( cd usr/share/doc/HTML/et/lilo-config ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kuser ; rm -rf common )
( cd usr/share/doc/HTML/et/kuser ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ksysv ; rm -rf common )
( cd usr/share/doc/HTML/et/ksysv ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/knetworkconf ; rm -rf common )
( cd usr/share/doc/HTML/et/knetworkconf ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcron ; rm -rf common )
( cd usr/share/doc/HTML/et/kcron ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kdat ; rm -rf common )
( cd usr/share/doc/HTML/et/kdat ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kpackage ; rm -rf common )
( cd usr/share/doc/HTML/et/kpackage ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/akregator ; rm -rf common )
( cd usr/share/doc/HTML/et/akregator ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kaddressbook ; rm -rf common )
( cd usr/share/doc/HTML/et/kaddressbook ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kpilot ; rm -rf common )
( cd usr/share/doc/HTML/et/kpilot ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kontact ; rm -rf common )
( cd usr/share/doc/HTML/et/kontact ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/knode ; rm -rf common )
( cd usr/share/doc/HTML/et/knode ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kleopatra ; rm -rf common )
( cd usr/share/doc/HTML/et/kleopatra ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kwatchgnupg ; rm -rf common )
( cd usr/share/doc/HTML/et/kwatchgnupg ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ktnef ; rm -rf common )
( cd usr/share/doc/HTML/et/ktnef ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konsolekalendar ; rm -rf common )
( cd usr/share/doc/HTML/et/konsolekalendar ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kandy ; rm -rf common )
( cd usr/share/doc/HTML/et/kandy ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kmail ; rm -rf common )
( cd usr/share/doc/HTML/et/kmail ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/knotes ; rm -rf common )
( cd usr/share/doc/HTML/et/knotes ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/multisynk ; rm -rf common )
( cd usr/share/doc/HTML/et/multisynk ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/korganizer ; rm -rf common )
( cd usr/share/doc/HTML/et/korganizer ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kalarm ; rm -rf common )
( cd usr/share/doc/HTML/et/kalarm ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/korn ; rm -rf common )
( cd usr/share/doc/HTML/et/korn ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/karm ; rm -rf common )
( cd usr/share/doc/HTML/et/karm ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kweather ; rm -rf common )
( cd usr/share/doc/HTML/et/kweather ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kodo ; rm -rf common )
( cd usr/share/doc/HTML/et/kodo ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kworldclock ; rm -rf common )
( cd usr/share/doc/HTML/et/kworldclock ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/amor ; rm -rf common )
( cd usr/share/doc/HTML/et/amor ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kteatime ; rm -rf common )
( cd usr/share/doc/HTML/et/kteatime ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kmoon ; rm -rf common )
( cd usr/share/doc/HTML/et/kmoon ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/khangman ; rm -rf common )
( cd usr/share/doc/HTML/et/khangman ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kvoctrain ; rm -rf common )
( cd usr/share/doc/HTML/et/kvoctrain ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kpercentage ; rm -rf common )
( cd usr/share/doc/HTML/et/kpercentage ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kiten ; rm -rf common )
( cd usr/share/doc/HTML/et/kiten ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kwordquiz ; rm -rf common )
( cd usr/share/doc/HTML/et/kwordquiz ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kmessedwords ; rm -rf common )
( cd usr/share/doc/HTML/et/kmessedwords ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kstars ; rm -rf common )
( cd usr/share/doc/HTML/et/kstars ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/keduca ; rm -rf common )
( cd usr/share/doc/HTML/et/keduca ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kig ; rm -rf common )
( cd usr/share/doc/HTML/et/kig ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kbruch ; rm -rf common )
( cd usr/share/doc/HTML/et/kbruch ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/flashkard ; rm -rf common )
( cd usr/share/doc/HTML/et/flashkard ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/klettres ; rm -rf common )
( cd usr/share/doc/HTML/et/klettres ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/blinken ; rm -rf common )
( cd usr/share/doc/HTML/et/blinken ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/klatin ; rm -rf common )
( cd usr/share/doc/HTML/et/klatin ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ktouch ; rm -rf common )
( cd usr/share/doc/HTML/et/ktouch ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kgeography ; rm -rf common )
( cd usr/share/doc/HTML/et/kgeography ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kmathtool ; rm -rf common )
( cd usr/share/doc/HTML/et/kmathtool ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kverbos ; rm -rf common )
( cd usr/share/doc/HTML/et/kverbos ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kalzium ; rm -rf common )
( cd usr/share/doc/HTML/et/kalzium ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kturtle ; rm -rf common )
( cd usr/share/doc/HTML/et/kturtle ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kmplot ; rm -rf common )
( cd usr/share/doc/HTML/et/kmplot ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kanagram ; rm -rf common )
( cd usr/share/doc/HTML/et/kanagram ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kde_app_devel ; rm -rf common )
( cd usr/share/doc/HTML/et/kde_app_devel ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kdevelop ; rm -rf common )
( cd usr/share/doc/HTML/et/kdevelop ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kdearch ; rm -rf common )
( cd usr/share/doc/HTML/et/kdearch ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/umbrello ; rm -rf common )
( cd usr/share/doc/HTML/et/umbrello ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kbabel ; rm -rf common )
( cd usr/share/doc/HTML/et/kbabel ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kdesvn-build ; rm -rf common )
( cd usr/share/doc/HTML/et/kdesvn-build ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kompare ; rm -rf common )
( cd usr/share/doc/HTML/et/kompare ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kbugbuster ; rm -rf common )
( cd usr/share/doc/HTML/et/kbugbuster ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/cervisia ; rm -rf common )
( cd usr/share/doc/HTML/et/cervisia ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kcachegrind ; rm -rf common )
( cd usr/share/doc/HTML/et/kcachegrind ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kicker-applets ; rm -rf common )
( cd usr/share/doc/HTML/et/kicker-applets ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konq-plugins ; rm -rf common )
( cd usr/share/doc/HTML/et/konq-plugins ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konq-plugins/uachanger ; rm -rf common )
( cd usr/share/doc/HTML/et/konq-plugins/uachanger ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konq-plugins/dirfilter ; rm -rf common )
( cd usr/share/doc/HTML/et/konq-plugins/dirfilter ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konq-plugins/babel ; rm -rf common )
( cd usr/share/doc/HTML/et/konq-plugins/babel ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konq-plugins/fsview ; rm -rf common )
( cd usr/share/doc/HTML/et/konq-plugins/fsview ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konq-plugins/smbmounter ; rm -rf common )
( cd usr/share/doc/HTML/et/konq-plugins/smbmounter ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konq-plugins/webarchiver ; rm -rf common )
( cd usr/share/doc/HTML/et/konq-plugins/webarchiver ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konq-plugins/imgallery ; rm -rf common )
( cd usr/share/doc/HTML/et/konq-plugins/imgallery ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konq-plugins/domtreeviewer ; rm -rf common )
( cd usr/share/doc/HTML/et/konq-plugins/domtreeviewer ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konq-plugins/validators ; rm -rf common )
( cd usr/share/doc/HTML/et/konq-plugins/validators ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konq-plugins/crashes ; rm -rf common )
( cd usr/share/doc/HTML/et/konq-plugins/crashes ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konq-plugins/mediaplayer ; rm -rf common )
( cd usr/share/doc/HTML/et/konq-plugins/mediaplayer ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konq-plugins/kuick ; rm -rf common )
( cd usr/share/doc/HTML/et/konq-plugins/kuick ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konq-plugins/khtmlsettings ; rm -rf common )
( cd usr/share/doc/HTML/et/konq-plugins/khtmlsettings ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kate-plugins ; rm -rf common )
( cd usr/share/doc/HTML/et/kate-plugins ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ksig ; rm -rf common )
( cd usr/share/doc/HTML/et/ksig ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/lskat ; rm -rf common )
( cd usr/share/doc/HTML/et/lskat ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kfouleggs ; rm -rf common )
( cd usr/share/doc/HTML/et/kfouleggs ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kwin4 ; rm -rf common )
( cd usr/share/doc/HTML/et/kwin4 ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kreversi ; rm -rf common )
( cd usr/share/doc/HTML/et/kreversi ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kgoldrunner ; rm -rf common )
( cd usr/share/doc/HTML/et/kgoldrunner ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kpat ; rm -rf common )
( cd usr/share/doc/HTML/et/kpat ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konquest ; rm -rf common )
( cd usr/share/doc/HTML/et/konquest ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kmines ; rm -rf common )
( cd usr/share/doc/HTML/et/kmines ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/klines ; rm -rf common )
( cd usr/share/doc/HTML/et/klines ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ksokoban ; rm -rf common )
( cd usr/share/doc/HTML/et/ksokoban ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ksame ; rm -rf common )
( cd usr/share/doc/HTML/et/ksame ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kpoker ; rm -rf common )
( cd usr/share/doc/HTML/et/kpoker ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kbackgammon ; rm -rf common )
( cd usr/share/doc/HTML/et/kbackgammon ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kenolaba ; rm -rf common )
( cd usr/share/doc/HTML/et/kenolaba ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kjumpingcube ; rm -rf common )
( cd usr/share/doc/HTML/et/kjumpingcube ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kbattleship ; rm -rf common )
( cd usr/share/doc/HTML/et/kbattleship ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ksmiletris ; rm -rf common )
( cd usr/share/doc/HTML/et/ksmiletris ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ksnake ; rm -rf common )
( cd usr/share/doc/HTML/et/ksnake ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kspaceduel ; rm -rf common )
( cd usr/share/doc/HTML/et/kspaceduel ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kblackbox ; rm -rf common )
( cd usr/share/doc/HTML/et/kblackbox ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ksirtet ; rm -rf common )
( cd usr/share/doc/HTML/et/ksirtet ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kshisen ; rm -rf common )
( cd usr/share/doc/HTML/et/kshisen ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/atlantik ; rm -rf common )
( cd usr/share/doc/HTML/et/atlantik ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kbounce ; rm -rf common )
( cd usr/share/doc/HTML/et/kbounce ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kasteroids ; rm -rf common )
( cd usr/share/doc/HTML/et/kasteroids ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ktron ; rm -rf common )
( cd usr/share/doc/HTML/et/ktron ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kolf ; rm -rf common )
( cd usr/share/doc/HTML/et/kolf ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ktuberling ; rm -rf common )
( cd usr/share/doc/HTML/et/ktuberling ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/klickety ; rm -rf common )
( cd usr/share/doc/HTML/et/klickety ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kmahjongg ; rm -rf common )
( cd usr/share/doc/HTML/et/kmahjongg ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/katomic ; rm -rf common )
( cd usr/share/doc/HTML/et/katomic ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kmag ; rm -rf common )
( cd usr/share/doc/HTML/et/kmag ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kmouth ; rm -rf common )
( cd usr/share/doc/HTML/et/kmouth ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kttsd ; rm -rf common )
( cd usr/share/doc/HTML/et/kttsd ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kmousetool ; rm -rf common )
( cd usr/share/doc/HTML/et/kmousetool ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/juk ; rm -rf common )
( cd usr/share/doc/HTML/et/juk ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kioslave ; rm -rf common )
( cd usr/share/doc/HTML/et/kioslave ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/noatun ; rm -rf common )
( cd usr/share/doc/HTML/et/noatun ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kaboodle ; rm -rf common )
( cd usr/share/doc/HTML/et/kaboodle ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kmid ; rm -rf common )
( cd usr/share/doc/HTML/et/kmid ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/krec ; rm -rf common )
( cd usr/share/doc/HTML/et/krec ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kmix ; rm -rf common )
( cd usr/share/doc/HTML/et/kmix ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kaudiocreator ; rm -rf common )
( cd usr/share/doc/HTML/et/kaudiocreator ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kscd ; rm -rf common )
( cd usr/share/doc/HTML/et/kscd ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kdcop ; rm -rf common )
( cd usr/share/doc/HTML/et/kdcop ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kpager ; rm -rf common )
( cd usr/share/doc/HTML/et/kpager ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kdeprint ; rm -rf common )
( cd usr/share/doc/HTML/et/kdeprint ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/knetattach ; rm -rf common )
( cd usr/share/doc/HTML/et/knetattach ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/klipper ; rm -rf common )
( cd usr/share/doc/HTML/et/klipper ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ksplashml ; rm -rf common )
( cd usr/share/doc/HTML/et/ksplashml ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/khelpcenter/glossary ; rm -rf common )
( cd usr/share/doc/HTML/et/khelpcenter/glossary ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/khelpcenter/quickstart ; rm -rf common )
( cd usr/share/doc/HTML/et/khelpcenter/quickstart ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/khelpcenter/userguide ; rm -rf common )
( cd usr/share/doc/HTML/et/khelpcenter/userguide ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/khelpcenter ; rm -rf common )
( cd usr/share/doc/HTML/et/khelpcenter ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/khelpcenter/faq ; rm -rf common )
( cd usr/share/doc/HTML/et/khelpcenter/faq ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/khelpcenter/visualdict ; rm -rf common )
( cd usr/share/doc/HTML/et/khelpcenter/visualdict ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kdebugdialog ; rm -rf common )
( cd usr/share/doc/HTML/et/kdebugdialog ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kdesu ; rm -rf common )
( cd usr/share/doc/HTML/et/kdesu ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kate ; rm -rf common )
( cd usr/share/doc/HTML/et/kate ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kompmgr ; rm -rf common )
( cd usr/share/doc/HTML/et/kompmgr ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konqueror ; rm -rf common )
( cd usr/share/doc/HTML/et/konqueror ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kwrite ; rm -rf common )
( cd usr/share/doc/HTML/et/kwrite ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kfind ; rm -rf common )
( cd usr/share/doc/HTML/et/kfind ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/konsole ; rm -rf common )
( cd usr/share/doc/HTML/et/konsole ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kxkb ; rm -rf common )
( cd usr/share/doc/HTML/et/kxkb ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kdm ; rm -rf common )
( cd usr/share/doc/HTML/et/kdm ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/ksysguard ; rm -rf common )
( cd usr/share/doc/HTML/et/ksysguard ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kicker ; rm -rf common )
( cd usr/share/doc/HTML/et/kicker ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kmenuedit ; rm -rf common )
( cd usr/share/doc/HTML/et/kmenuedit ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kspell ; rm -rf common )
( cd usr/share/doc/HTML/et/kspell ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kommander ; rm -rf common )
( cd usr/share/doc/HTML/et/kommander ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kxsldbg ; rm -rf common )
( cd usr/share/doc/HTML/et/kxsldbg ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/klinkstatus ; rm -rf common )
( cd usr/share/doc/HTML/et/klinkstatus ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/xsldbg ; rm -rf common )
( cd usr/share/doc/HTML/et/xsldbg ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/quanta ; rm -rf common )
( cd usr/share/doc/HTML/et/quanta ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/et/kfilereplace ; rm -rf common )
( cd usr/share/doc/HTML/et/kfilereplace ; ln -sf /usr/share/doc/HTML/et/common common )
